@@ -5,7 +5,7 @@ import click
 
 from mldock.platform_helpers.docker.auth import login_and_authenticate
 from mldock.api.local import docker_build
-from mldock.api.registry import push_image_to_repository, pull_image_from_repository
+from mldock.api.registry import push_image_to_repository, pull_image_from_repository, tag_image
 from mldock.config_managers.project import MLDockConfigManager
 from mldock.terminal import ProgressLogger, pretty_build_logs
 
@@ -55,6 +55,7 @@ def registry():
     type=click.Choice(["ecr", "gcr", "dockerhub"], case_sensitive=False),
 )
 @click.option("--region", help="Set the registry region", default=None, type=str)
+@click.option("--image", help="prebuilt image name to push to remote registry", type=str, default=None)
 @click.option("--tag", help="docker tag", type=str, default="latest")
 @click.option("--stage", help="environment to stage.")
 @click.pass_obj
@@ -66,12 +67,14 @@ def push(obj, project_directory, provider, **kwargs):
     stage = kwargs.get("stage", None)
     region = kwargs.get("region", None)
     build = kwargs.get("build", False)
+    image = kwargs.get("image", None)
     reset_terminal()
     mldock_manager = MLDockConfigManager(
         filepath=os.path.join(project_directory, MLDOCK_CONFIG_NAME)
     )
     # get mldock_module_dir name
     mldock_config = mldock_manager.get_config()
+    local_image_name = mldock_config.get('image_name', None)
     module_path = os.path.join(
         project_directory,
         mldock_config.get("mldock_module_dir", "src"),
@@ -111,7 +114,7 @@ def push(obj, project_directory, provider, **kwargs):
     ) as spinner:
         _, metadata = login_and_authenticate(provider=provider, region=region)
         image_repository = (
-            f"{metadata['repository']}/{mldock_config.get('image_name', None)}"
+            f"{metadata['repository']}/{local_image_name}"
         )
 
     if build:
@@ -132,6 +135,10 @@ def push(obj, project_directory, provider, **kwargs):
 
                 spinner.start()
 
+    elif image is not None:
+        logger.info(f"tagging image: {image_repository}:{tag} => {local_image_name}:{tag}")
+        tag_image(f"{image}:{tag}", local_image_name, tag)
+
     # Push image to cloud repository
     with ProgressLogger(
         group="Push", text="Pushing to {}".format(image_repository), spinner="dots"
@@ -197,6 +204,7 @@ def pull(obj, project_directory, provider, **kwargs):
 
     # get mldock_module_dir name
     mldock_config = mldock_manager.get_config()
+    local_image_name = mldock_config.get('image_name', None)
 
     # retrieve stages
     with ProgressLogger(
@@ -222,8 +230,9 @@ def pull(obj, project_directory, provider, **kwargs):
         spinner="dots",
     ) as spinner:
         _, metadata = login_and_authenticate(provider=provider, region=region)
+
         image_repository = (
-            f"{metadata['repository']}/{mldock_config.get('image_name', None)}"
+            f"{metadata['repository']}/{local_image_name}"
         )
 
     # Push image to cloud repository
@@ -248,6 +257,10 @@ def pull(obj, project_directory, provider, **kwargs):
         logger.info(obj["logo"])
         spinner.start()
 
+    # tag as new image
+    logger.info(f"tagging image: {image_repository}:{tag} => {local_image_name}:{tag}")
+    tag_image(f"{image_repository}:{tag}", local_image_name, tag)
+
 
 def add_commands(cli_group: click.group):
     """
