@@ -8,7 +8,8 @@ from mldock.platform_helpers.aws.auth import get_aws_ecr
 from mldock.platform_helpers.gcp.auth import get_gcp_gcr
 from mldock.platform_helpers.dockerhub.auth import get_dockerhub_credentials
 
-logger = logging.getLogger('mldock')
+logger = logging.getLogger("mldock")
+
 
 def login_and_authenticate(provider: str, region: str):
     """
@@ -16,31 +17,29 @@ def login_and_authenticate(provider: str, region: str):
     """
     client = docker.from_env()
 
-    if provider == 'ecr':
+    if provider == "ecr":
         # AWS ECR
         username, password, registry, repo = get_aws_ecr(region=region)
-    elif provider == 'gcr':
+    elif provider == "gcr":
         # GCP
         username, password, registry, repo = get_gcp_gcr(region=region)
-    elif provider == 'dockerhub':
+    elif provider == "dockerhub":
         # DockerHub
         username, password, registry, repo = get_dockerhub_credentials()
     else:
-        raise TypeError("{PROVIDER} Registry is not implemented.".format(PROVIDER=provider))
+        raise TypeError(
+            "{PROVIDER} Registry is not implemented.".format(PROVIDER=provider)
+        )
 
     # login
     _ = client.login(
-        username=username,
-        password=password,
-        email=None,
-        registry=registry,
-        reauth=True
+        username=username, password=password, email=None, registry=registry, reauth=True
     )
 
     # return logged in client
     return client, {
-        'username': username,
-        'password': password,
-        'registry': registry,
-        'repository': repo
+        "username": username,
+        "password": password,
+        "registry": registry,
+        "repository": repo,
     }
